package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DEREnumerated;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.util.ASN1Dump;
import cn.com.infosec.asn1.x509.CRLReason;
import cn.com.infosec.asn1.x509.GeneralName;
import cn.com.infosec.asn1.x509.GeneralNames;
import cn.com.infosec.asn1.x509.TBSCertList;
import cn.com.infosec.asn1.x509.X509Extension;
import cn.com.infosec.asn1.x509.X509Extensions;
import cn.com.infosec.x509.extension.X509ExtensionUtil;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.math.BigInteger;
import java.security.cert.CRLException;
import java.security.cert.X509CRLEntry;
import java.util.Date;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Set;
import javax.security.auth.x500.X500Principal;

public class X509CRLEntryObject extends X509CRLEntry {
   private TBSCertList.CRLEntry c;
   private boolean isIndirect;
   private X500Principal previousCertificateIssuer;
   private X500Principal certificateIssuer;
   private int hashValue;
   private boolean isHashValueSet;

   public X509CRLEntryObject(TBSCertList.CRLEntry c) {
      this.c = c;
      this.certificateIssuer = this.loadCertificateIssuer();
   }

   public X509CRLEntryObject(TBSCertList.CRLEntry c, boolean isIndirect, X500Principal previousCertificateIssuer) {
      this.c = c;
      this.isIndirect = isIndirect;
      this.previousCertificateIssuer = previousCertificateIssuer;
      this.certificateIssuer = this.loadCertificateIssuer();
   }

   private X500Principal loadCertificateIssuer() {
      if (!this.isIndirect) {
         return null;
      } else {
         byte[] var1;
         if ((var1 = this.getExtensionValue(X509Extensions.CertificateIssuer.getId())) == null) {
            return this.previousCertificateIssuer;
         } else {
            GeneralName[] var10000;
            boolean var10001;
            try {
               var10000 = GeneralNames.getInstance(X509ExtensionUtil.fromExtensionValue(var1)).getNames();
            } catch (IOException var5) {
               var10001 = false;
               return null;
            }

            GeneralName[] var6 = var10000;
            int var7 = 0;

            while(true) {
               int var8;
               int var9;
               try {
                  var8 = var7;
                  var9 = var6.length;
               } catch (IOException var3) {
                  var10001 = false;
                  break;
               }

               if (var8 >= var9) {
                  return null;
               }

               try {
                  var8 = var6[var7].getTagNo();
               } catch (IOException var4) {
                  var10001 = false;
                  break;
               }

               if (var8 == 4) {
                  try {
                     return new X500Principal(var6[var7].getName().getDERObject().getDEREncoded());
                  } catch (IOException var2) {
                     var10001 = false;
                     break;
                  }
               }

               ++var7;
            }

            return null;
         }
      }
   }

   private Set getExtensionOIDs(boolean critical) {
      X509Extensions var5;
      if ((var5 = this.c.getExtensions()) != null) {
         HashSet var2;
         var2 = new HashSet.<init>();
         Enumeration var3 = var5.oids();

         while(var3.hasMoreElements()) {
            DERObjectIdentifier var4;
            if (critical == var5.getExtension(var4 = (DERObjectIdentifier)var3.nextElement()).isCritical()) {
               var2.add(var4.getId());
            }
         }

         return var2;
      } else {
         return null;
      }
   }

   public boolean hasUnsupportedCriticalExtension() {
      Set var1;
      return (var1 = this.getCriticalExtensionOIDs()) != null && !var1.isEmpty();
   }

   public X500Principal getCertificateIssuer() {
      return this.certificateIssuer;
   }

   public Set getCriticalExtensionOIDs() {
      return this.getExtensionOIDs(true);
   }

   public Set getNonCriticalExtensionOIDs() {
      return this.getExtensionOIDs(false);
   }

   public byte[] getExtensionValue(String oid) {
      X509Extensions var3;
      if ((var3 = this.c.getExtensions()) != null) {
         X509Extensions var10000 = var3;
         DERObjectIdentifier var4;
         var4 = new DERObjectIdentifier.<init>(oid);
         X509Extension var5;
         if ((var5 = var10000.getExtension(var4)) != null) {
            try {
               return var5.getValue().getEncoded();
            } catch (Exception var2) {
               throw new RuntimeException("error encoding " + var2.toString());
            }
         }
      }

      return null;
   }

   public int hashCode() {
      if (!this.isHashValueSet) {
         this.hashValue = super.hashCode();
         this.isHashValueSet = true;
      }

      return this.hashValue;
   }

   public byte[] getEncoded() {
      ByteArrayOutputStream var1;
      ByteArrayOutputStream var10000 = var1 = new ByteArrayOutputStream;
      var10000.<init>();
      X509CRLEntryObject var10002 = this;
      DEROutputStream var10001 = new DEROutputStream(var1);

      try {
         var10001.writeObject(var10002.c);
         return var10000.toByteArray();
      } catch (IOException var2) {
         throw new CRLException(var2.toString());
      }
   }

   public BigInteger getSerialNumber() {
      return this.c.getUserCertificate().getValue();
   }

   public Date getRevocationDate() {
      return this.c.getRevocationDate().getDate();
   }

   public boolean hasExtensions() {
      return this.c.getExtensions() != null;
   }

   public String toString() {
      StringBuffer var1;
      StringBuffer var10001 = var1 = new StringBuffer;
      var10001.<init>();
      String var2 = System.getProperty("line.separator");
      var10001.append("      userCertificate: ").append(this.getSerialNumber()).append(var2);
      var10001.append("       revocationDate: ").append(this.getRevocationDate()).append(var2);
      var10001.append("       certificateIssuer: ").append(this.getCertificateIssuer()).append(var2);
      Enumeration var3;
      X509Extensions var14;
      if ((var14 = this.c.getExtensions()) != null && (var3 = var14.oids()).hasMoreElements()) {
         var1.append("   crlEntryExtensions:").append(var2);

         while(true) {
            while(true) {
               while(var3.hasMoreElements()) {
                  DERObjectIdentifier var4;
                  X509Extension var5;
                  if ((var5 = var14.getExtension(var4 = (DERObjectIdentifier)var3.nextElement())).getValue() != null) {
                     DERObjectIdentifier var10000 = var4;
                     byte[] var6 = var5.getValue().getOctets();
                     ASN1InputStream var7;
                     var7 = new ASN1InputStream.<init>(var6);
                     var1.append("                       critical(").append(var5.isCritical()).append(") ");

                     label63: {
                        boolean var15;
                        boolean var17;
                        try {
                           var15 = var10000.equals(X509Extensions.ReasonCode);
                        } catch (Exception var13) {
                           var17 = false;
                           break label63;
                        }

                        if (var15) {
                           try {
                              var1.append(new CRLReason(DEREnumerated.getInstance(var7.readObject()))).append(var2);
                              continue;
                           } catch (Exception var8) {
                              var17 = false;
                           }
                        } else {
                           label59: {
                              try {
                                 var15 = var4.equals(X509Extensions.CertificateIssuer);
                              } catch (Exception var12) {
                                 var17 = false;
                                 break label59;
                              }

                              if (var15) {
                                 try {
                                    var1.append("Certificate issuer: ").append(new GeneralNames((ASN1Sequence)var7.readObject())).append(var2);
                                    continue;
                                 } catch (Exception var9) {
                                    var17 = false;
                                 }
                              } else {
                                 label75: {
                                    StringBuffer var16;
                                    try {
                                       var16 = var1;
                                       var1.append(var4.getId());
                                    } catch (Exception var11) {
                                       var17 = false;
                                       break label75;
                                    }

                                    try {
                                       var16.append(" value = ").append(ASN1Dump.dumpAsString(var7.readObject())).append(var2);
                                       continue;
                                    } catch (Exception var10) {
                                       var17 = false;
                                    }
                                 }
                              }
                           }
                        }
                     }

                     var1.append(var4.getId());
                     var1.append(" value = ").append("*****").append(var2);
                  } else {
                     var1.append(var2);
                  }
               }

               return var1.toString();
            }
         }
      } else {
         return var1.toString();
      }
   }
}
